diff --git a/composer.json b/composer.json
index 7d5a865f5aa6625e8ae506a5301f8c6679ced0f0..1cbd00864dbe71a43a436457f6e86dd21bf098d7 100644
--- a/composer.json
+++ b/composer.json
@@ -125,7 +125,6 @@
 		"typo3/cms-saltedpasswords": "self.version",
 		"typo3/cms-scheduler": "self.version",
 		"typo3/cms-setup": "self.version",
-		"typo3/cms-sv": "self.version",
 		"typo3/cms-sys-action": "self.version",
 		"typo3/cms-sys-note": "self.version",
 		"typo3/cms-t3editor": "self.version",
@@ -176,7 +175,6 @@
 			"TYPO3\\CMS\\Saltedpasswords\\": "typo3/sysext/saltedpasswords/Classes/",
 			"TYPO3\\CMS\\Scheduler\\": "typo3/sysext/scheduler/Classes/",
 			"TYPO3\\CMS\\Setup\\": "typo3/sysext/setup/Classes/",
-			"TYPO3\\CMS\\Sv\\": "typo3/sysext/sv/Classes/",
 			"TYPO3\\CMS\\SysAction\\": "typo3/sysext/sys_action/Classes/",
 			"TYPO3\\CMS\\SysNote\\": "typo3/sysext/sys_note/Classes/",
 			"TYPO3\\CMS\\T3editor\\": "typo3/sysext/t3editor/Classes/",
@@ -220,7 +218,6 @@
 			"TYPO3\\CMS\\Rsaauth\\Tests\\": "typo3/sysext/rsaauth/Tests/",
 			"TYPO3\\CMS\\Saltedpasswords\\Tests\\": "typo3/sysext/saltedpasswords/Tests/",
 			"TYPO3\\CMS\\Scheduler\\Tests\\": "typo3/sysext/scheduler/Tests/",
-			"TYPO3\\CMS\\Sv\\Tests\\": "typo3/sysext/sv/Tests/",
 			"TYPO3\\CMS\\SysAction\\Tests\\": "typo3/sysext/sys_action/Tests/",
 			"TYPO3\\CMS\\SysNote\\Tests\\": "typo3/sysext/sys_note/Tests/",
 			"TYPO3\\CMS\\Workspaces\\Tests\\": "typo3/sysext/workspaces/Tests/",
diff --git a/composer.lock b/composer.lock
index 981dd9286483deeb91b258172abe040f0750a4ba..2cb1911c8f06d639c45c75ba5e2a6fc650275722 100644
--- a/composer.lock
+++ b/composer.lock
@@ -4,7 +4,7 @@
         "Read more about it at https://getcomposer.org/doc/01-basic-usage.md#composer-lock-the-lock-file",
         "This file is @generated automatically"
     ],
-    "content-hash": "38b5eeddadb3daba2d9fd4f6706b16e9",
+    "content-hash": "546e2c9d87c42a0c785bb55ec036056a",
     "packages": [
         {
             "name": "cogpowered/finediff",
diff --git a/typo3/sysext/sv/Classes/AbstractAuthenticationService.php b/typo3/sysext/core/Classes/Authentication/AbstractAuthenticationService.php
similarity index 98%
rename from typo3/sysext/sv/Classes/AbstractAuthenticationService.php
rename to typo3/sysext/core/Classes/Authentication/AbstractAuthenticationService.php
index ff52a2f344bc65952ac875f53de8a25473761511..daa7059c7773c03632d36fa5c860fb062ab42bcc 100644
--- a/typo3/sysext/sv/Classes/AbstractAuthenticationService.php
+++ b/typo3/sysext/core/Classes/Authentication/AbstractAuthenticationService.php
@@ -1,5 +1,5 @@
 <?php
-namespace TYPO3\CMS\Sv;
+namespace TYPO3\CMS\Core\Authentication;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,7 +14,6 @@ namespace TYPO3\CMS\Sv;
  * The TYPO3 project - inspiring people to share!
  */
 
-use TYPO3\CMS\Core\Authentication\AbstractUserAuthentication;
 use TYPO3\CMS\Core\Service\AbstractService;
 
 /**
diff --git a/typo3/sysext/core/Classes/Authentication/AbstractUserAuthentication.php b/typo3/sysext/core/Classes/Authentication/AbstractUserAuthentication.php
index 0fd2b54017f21c57caf80572235631b2f19d1e1c..0941a85050b243e6b62cf3e9674470ad9dfd2b07 100644
--- a/typo3/sysext/core/Classes/Authentication/AbstractUserAuthentication.php
+++ b/typo3/sysext/core/Classes/Authentication/AbstractUserAuthentication.php
@@ -32,7 +32,6 @@ use TYPO3\CMS\Core\Session\Backend\SessionBackendInterface;
 use TYPO3\CMS\Core\Session\SessionManager;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\MathUtility;
-use TYPO3\CMS\Sv\AuthenticationService;
 
 /**
  * Authentication of users in TYPO3
@@ -662,7 +661,6 @@ abstract class AbstractUserAuthentication
             // Use 'auth' service to find the user
             // First found user will be used
             $subType = 'getUser' . $this->loginType;
-            /** @var AuthenticationService $serviceObj */
             foreach ($this->getAuthServices($subType, $loginData, $authInfo) as $serviceObj) {
                 if ($row = $serviceObj->getUser()) {
                     $tempuserArr[] = $row;
diff --git a/typo3/sysext/sv/Classes/AuthenticationService.php b/typo3/sysext/core/Classes/Authentication/AuthenticationService.php
similarity index 99%
rename from typo3/sysext/sv/Classes/AuthenticationService.php
rename to typo3/sysext/core/Classes/Authentication/AuthenticationService.php
index 338bc9d49d24d6d9b8c16c17955268bee2c38866..f3307191bb37ee1adafdb79290281afe53e6cbd6 100644
--- a/typo3/sysext/sv/Classes/AuthenticationService.php
+++ b/typo3/sysext/core/Classes/Authentication/AuthenticationService.php
@@ -1,5 +1,5 @@
 <?php
-namespace TYPO3\CMS\Sv;
+namespace TYPO3\CMS\Core\Authentication;
 
 /*
  * This file is part of the TYPO3 CMS project.
diff --git a/typo3/sysext/core/Documentation/Changelog/master/Breaking-81735-GetRidOfSysextsv.rst b/typo3/sysext/core/Documentation/Changelog/master/Breaking-81735-GetRidOfSysextsv.rst
new file mode 100644
index 0000000000000000000000000000000000000000..707574dbe42880b5e0f8f8e1688f6dc406876b0b
--- /dev/null
+++ b/typo3/sysext/core/Documentation/Changelog/master/Breaking-81735-GetRidOfSysextsv.rst
@@ -0,0 +1,32 @@
+.. include:: ../../Includes.txt
+
+=======================================
+Breaking: #81735 - Get rid of sysext:sv
+=======================================
+
+See :issue:`81735`
+
+Description
+===========
+
+The AuthenticationService has been moved into sysext:core. Class aliases are in place and will be removed with TYPO3 v10.
+
+
+Impact
+======
+
+The namespace of the classes :php:`AbstractAuthenticationService` and :php:`AuthenticationService` changed from :php:`\TYPO3\CMS\Sv` to :php:`\TYPO3\CMS\Core\Authentication`.
+
+
+Affected Installations
+======================
+
+All instances, that use or extend the mentioned classes.
+
+
+Migration
+=========
+
+Use the new namespaces as mentioned above.
+
+.. index:: Backend, PHP-API
\ No newline at end of file
diff --git a/typo3/sysext/core/Migrations/Code/ClassAliasMap.php b/typo3/sysext/core/Migrations/Code/ClassAliasMap.php
index 422fa7fc4e8ea0ad0853d58a2a2ee9930c363ff0..cf0a15d26722c7d5242111e4e2daa18bafb0e54c 100644
--- a/typo3/sysext/core/Migrations/Code/ClassAliasMap.php
+++ b/typo3/sysext/core/Migrations/Code/ClassAliasMap.php
@@ -1,5 +1,7 @@
 <?php
 return [
     'TYPO3\\CMS\\Lang\\LanguageService' => \TYPO3\CMS\Core\Localization\LanguageService::class,
-    'TYPO3\\CMS\\ContextHelp\\Controller\\ContextHelpAjaxController' => \TYPO3\CMS\Backend\Controller\ContextHelpAjaxController::class
+    'TYPO3\\CMS\\ContextHelp\\Controller\\ContextHelpAjaxController' => \TYPO3\CMS\Backend\Controller\ContextHelpAjaxController::class,
+    'TYPO3\\CMS\\Sv\\AbstractAuthenticationService' => \TYPO3\CMS\Core\Authentication\AbstractAuthenticationService::class,
+    'TYPO3\\CMS\\Sv\\AuthenticationService' => \TYPO3\CMS\Core\Authentication\AuthenticationService::class
 ];
diff --git a/typo3/sysext/core/Migrations/Code/LegacyClassesForIde.php b/typo3/sysext/core/Migrations/Code/LegacyClassesForIde.php
index 869c2019c80c649db06ae33292596853540f33ef..0e31e02774d64bbba9098d2daa477f159f36f81a 100644
--- a/typo3/sysext/core/Migrations/Code/LegacyClassesForIde.php
+++ b/typo3/sysext/core/Migrations/Code/LegacyClassesForIde.php
@@ -14,3 +14,12 @@ namespace TYPO3\CMS\ContextHelp\Controller {
     {
     }
 }
+
+namespace TYPO3\CMS\Sv {
+    class AbstractAuthenticationService extends \TYPO3\CMS\Core\Authentication\AbstractAuthenticationService
+    {
+    }
+    class AuthenticationService extends \TYPO3\CMS\Core\Authentication\AuthenticationService
+    {
+    }
+}
diff --git a/typo3/sysext/sv/Tests/Functional/Fixtures/be_users.xml b/typo3/sysext/core/Tests/Functional/Fixtures/be_users.xml
similarity index 100%
rename from typo3/sysext/sv/Tests/Functional/Fixtures/be_users.xml
rename to typo3/sysext/core/Tests/Functional/Fixtures/be_users.xml
diff --git a/typo3/sysext/sv/Tests/Unit/AuthenticationServiceTest.php b/typo3/sysext/core/Tests/Unit/Authentication/AuthenticationServiceTest.php
similarity index 87%
rename from typo3/sysext/sv/Tests/Unit/AuthenticationServiceTest.php
rename to typo3/sysext/core/Tests/Unit/Authentication/AuthenticationServiceTest.php
index db4e3485d044d0e7e354e21238059b1bba1b12ab..10fe66214f608fbb71daabb2b5566a7176c76770 100644
--- a/typo3/sysext/sv/Tests/Unit/AuthenticationServiceTest.php
+++ b/typo3/sysext/core/Tests/Unit/Authentication/AuthenticationServiceTest.php
@@ -1,5 +1,5 @@
 <?php
-namespace TYPO3\CMS\Sv\Tests\Unit;
+namespace TYPO3\CMS\Core\Tests\Unit\Authentication;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -13,9 +13,10 @@ namespace TYPO3\CMS\Sv\Tests\Unit;
  *
  * The TYPO3 project - inspiring people to share!
  */
+use TYPO3\CMS\Core\Authentication\AuthenticationService;
 
 /**
- * Testcase for class \TYPO3\CMS\Sv\AuthenticationService
+ * Testcase for class \TYPO3\CMS\Core\Authentication\AuthenticationService
  */
 class AuthenticationServiceTest extends \TYPO3\TestingFramework\Core\Unit\UnitTestCase
 {
@@ -64,8 +65,8 @@ class AuthenticationServiceTest extends \TYPO3\TestingFramework\Core\Unit\UnitTe
      */
     public function processLoginReturnsCorrectData($passwordSubmissionStrategy, $loginData, $expectedProcessedData)
     {
-        /** @var $authenticationService \TYPO3\CMS\Sv\AuthenticationService */
-        $authenticationService = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance(\TYPO3\CMS\Sv\AuthenticationService::class);
+        /** @var $authenticationService AuthenticationService */
+        $authenticationService = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance(AuthenticationService::class);
         // Login data is modified by reference
         $authenticationService->processLoginData($loginData, $passwordSubmissionStrategy);
         $this->assertEquals($expectedProcessedData, $loginData);
diff --git a/typo3/sysext/core/Tests/Unit/Service/DependencyOrderingServiceTest.php b/typo3/sysext/core/Tests/Unit/Service/DependencyOrderingServiceTest.php
index 3250024c25d75a21025fb438ee1402e72d3f8866..2b04e51245bb451f042949550122a287cacc46cb 100644
--- a/typo3/sysext/core/Tests/Unit/Service/DependencyOrderingServiceTest.php
+++ b/typo3/sysext/core/Tests/Unit/Service/DependencyOrderingServiceTest.php
@@ -410,44 +410,29 @@ class DependencyOrderingServiceTest extends \TYPO3\TestingFramework\Core\Unit\Un
                         'before' => [],
                         'after' => ['core'],
                     ],
-                    'sv' => [
-                        'before' => [],
-                        'after' => ['core'],
-                    ],
                 ],
                 [ // graph
                     'core' => [
                         'core' => false,
                         'setup' => false,
-                        'sv' => false,
                         'scheduler' => false,
                         'openid' => false,
                     ],
                     'openid' => [
                         'core' => true,
                         'setup' => true,
-                        'sv' => false,
                         'scheduler' => false,
                         'openid' => false,
                     ],
                     'scheduler' => [
                         'core' => true,
                         'setup' => false,
-                        'sv' => false,
                         'scheduler' => false,
                         'openid' => false,
                     ],
                     'setup' => [
                         'core' => true,
                         'setup' => false,
-                        'sv' => false,
-                        'scheduler' => false,
-                        'openid' => false,
-                    ],
-                    'sv' => [
-                        'core' => true,
-                        'setup' => false,
-                        'sv' => false,
                         'scheduler' => false,
                         'openid' => false,
                     ],
diff --git a/typo3/sysext/core/ext_localconf.php b/typo3/sysext/core/ext_localconf.php
index 89fc87ca957394df6eeb3e2887cd533b476dab3e..aba4f60d2f63b8e011e5451f66751d41156c8a02 100644
--- a/typo3/sysext/core/ext_localconf.php
+++ b/typo3/sysext/core/ext_localconf.php
@@ -1,4 +1,5 @@
 <?php
+
 defined('TYPO3_MODE') or die();
 
 /** @var \TYPO3\CMS\Extbase\SignalSlot\Dispatcher $signalSlotDispatcher */
@@ -102,3 +103,21 @@ unset($textExtractorRegistry);
 $extractorRegistry = \TYPO3\CMS\Core\Resource\Index\ExtractorRegistry::getInstance();
 $extractorRegistry->registerExtractionService(\TYPO3\CMS\Core\Resource\OnlineMedia\Metadata\Extractor::class);
 unset($extractorRegistry);
+
+// Register base authentication service
+\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::addService(
+    'core',
+    'auth',
+    \TYPO3\CMS\Core\Authentication\AuthenticationService::class,
+    [
+        'title' => 'User authentication',
+        'description' => 'Authentication with username/password.',
+        'subtype' => 'getUserBE,getUserFE,authUserFE,getGroupsFE,processLoginDataBE,processLoginDataFE',
+        'available' => true,
+        'priority' => 50,
+        'quality' => 50,
+        'os' => '',
+        'exec' => '',
+        'className' => TYPO3\CMS\Core\Authentication\AuthenticationService::class
+    ]
+);
diff --git a/typo3/sysext/extbase/Tests/Functional/Persistence/EnableFieldsTest.php b/typo3/sysext/extbase/Tests/Functional/Persistence/EnableFieldsTest.php
index c5331bc803bf2c0729c1772016fa5bad7e17d250..fbf7ea76aca2e1bded489effd9f55745f6c47198 100644
--- a/typo3/sysext/extbase/Tests/Functional/Persistence/EnableFieldsTest.php
+++ b/typo3/sysext/extbase/Tests/Functional/Persistence/EnableFieldsTest.php
@@ -31,7 +31,7 @@ class EnableFieldsTest extends AbstractDataHandlerActionTestCase
     /**
      * @var array
      */
-    protected $coreExtensionsToLoad = ['sv', 'extbase', 'fluid'];
+    protected $coreExtensionsToLoad = ['core', 'extbase', 'fluid'];
 
     /**
      * Sets up this test suite.
diff --git a/typo3/sysext/frontend/Tests/Unit/Authentication/FrontendUserAuthenticationTest.php b/typo3/sysext/frontend/Tests/Unit/Authentication/FrontendUserAuthenticationTest.php
index a4bf7310cefae417612a34b2b37d8946981d0a15..ca1aeeb572b3f4a6236bec449773458a6013b480 100644
--- a/typo3/sysext/frontend/Tests/Unit/Authentication/FrontendUserAuthenticationTest.php
+++ b/typo3/sysext/frontend/Tests/Unit/Authentication/FrontendUserAuthenticationTest.php
@@ -17,6 +17,7 @@ namespace TYPO3\CMS\Frontend\Tests\Unit\Authentication;
 
 use Doctrine\DBAL\Statement;
 use Prophecy\Argument;
+use TYPO3\CMS\Core\Authentication\AuthenticationService;
 use TYPO3\CMS\Core\Crypto\Random;
 use TYPO3\CMS\Core\Database\ConnectionPool;
 use TYPO3\CMS\Core\Database\Query\Expression\CompositeExpression;
@@ -27,7 +28,6 @@ use TYPO3\CMS\Core\Session\Backend\SessionBackendInterface;
 use TYPO3\CMS\Core\Session\SessionManager;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Frontend\Authentication\FrontendUserAuthentication;
-use TYPO3\CMS\Sv\AuthenticationService;
 use TYPO3\TestingFramework\Core\Unit\UnitTestCase;
 
 /**
diff --git a/typo3/sysext/saltedpasswords/Classes/SaltedPasswordService.php b/typo3/sysext/saltedpasswords/Classes/SaltedPasswordService.php
index 63cfd6d77cab54cabd4427054ad29f024e09d33e..ca31e93b0ea6545be7dc4b04753a85a08fd67c93 100644
--- a/typo3/sysext/saltedpasswords/Classes/SaltedPasswordService.php
+++ b/typo3/sysext/saltedpasswords/Classes/SaltedPasswordService.php
@@ -13,6 +13,7 @@ namespace TYPO3\CMS\Saltedpasswords;
  *
  * The TYPO3 project - inspiring people to share!
  */
+use TYPO3\CMS\Core\Authentication\AbstractAuthenticationService;
 use TYPO3\CMS\Core\Database\ConnectionPool;
 use TYPO3\CMS\Core\TimeTracker\TimeTracker;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
@@ -21,7 +22,7 @@ use TYPO3\CMS\Core\Utility\GeneralUtility;
  * Class implements salted-password hashes authentication service.
  * Contains authentication service class for salted hashed passwords.
  */
-class SaltedPasswordService extends \TYPO3\CMS\Sv\AbstractAuthenticationService
+class SaltedPasswordService extends AbstractAuthenticationService
 {
     /**
      * Keeps class name.
diff --git a/typo3/sysext/saltedpasswords/ext_localconf.php b/typo3/sysext/saltedpasswords/ext_localconf.php
index c8d96a5303a1ea5049392ce08e19b73b20cc4b68..12f964f6bd44e84490d870bccb58a8705734f3e6 100644
--- a/typo3/sysext/saltedpasswords/ext_localconf.php
+++ b/typo3/sysext/saltedpasswords/ext_localconf.php
@@ -18,7 +18,7 @@ $GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['ext/saltedpasswords']['saltMethods']
     'subtype' => 'authUserFE,authUserBE',
     'available' => true,
     'priority' => 70,
-    // must be higher than \TYPO3\CMS\Sv\AuthenticationService (50) and rsaauth (60) but lower than OpenID (75)
+    // must be higher than \TYPO3\CMS\Core\Authentication\AuthenticationService (50) and rsaauth (60) but lower than OpenID (75)
     'quality' => 70,
     'os' => '',
     'exec' => '',
diff --git a/typo3/sysext/sv/LICENSE.txt b/typo3/sysext/sv/LICENSE.txt
deleted file mode 100644
index 95d36a78ffce9a9ad8c4000f87603a76dd17e67e..0000000000000000000000000000000000000000
--- a/typo3/sysext/sv/LICENSE.txt
+++ /dev/null
@@ -1,345 +0,0 @@
-Some icons used in the TYPO3 project are retrieved from the "Silk" icon set of
-Mark James, which can be found at http://famfamfam.com/lab/icons/silk/. This
-set is distributed under a Creative Commons Attribution 2.5 License. The
-license can be found at http://creativecommons.org/licenses/by/2.5/.
----------------------------------
-
-                    GNU GENERAL PUBLIC LICENSE
-                       Version 2, June 1991
-
- Copyright (C) 1989, 1991 Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- Everyone is permitted to copy and distribute verbatim copies
- of this license document, but changing it is not allowed.
-
-                            Preamble
-
-  The licenses for most software are designed to take away your
-freedom to share and change it.  By contrast, the GNU General Public
-License is intended to guarantee your freedom to share and change free
-software--to make sure the software is free for all its users.  This
-General Public License applies to most of the Free Software
-Foundation's software and to any other program whose authors commit to
-using it.  (Some other Free Software Foundation software is covered by
-the GNU Lesser General Public License instead.)  You can apply it to
-your programs, too.
-
-  When we speak of free software, we are referring to freedom, not
-price.  Our General Public Licenses are designed to make sure that you
-have the freedom to distribute copies of free software (and charge for
-this service if you wish), that you receive source code or can get it
-if you want it, that you can change the software or use pieces of it
-in new free programs; and that you know you can do these things.
-
-  To protect your rights, we need to make restrictions that forbid
-anyone to deny you these rights or to ask you to surrender the rights.
-These restrictions translate to certain responsibilities for you if you
-distribute copies of the software, or if you modify it.
-
-  For example, if you distribute copies of such a program, whether
-gratis or for a fee, you must give the recipients all the rights that
-you have.  You must make sure that they, too, receive or can get the
-source code.  And you must show them these terms so they know their
-rights.
-
-  We protect your rights with two steps: (1) copyright the software, and
-(2) offer you this license which gives you legal permission to copy,
-distribute and/or modify the software.
-
-  Also, for each author's protection and ours, we want to make certain
-that everyone understands that there is no warranty for this free
-software.  If the software is modified by someone else and passed on, we
-want its recipients to know that what they have is not the original, so
-that any problems introduced by others will not reflect on the original
-authors' reputations.
-
-  Finally, any free program is threatened constantly by software
-patents.  We wish to avoid the danger that redistributors of a free
-program will individually obtain patent licenses, in effect making the
-program proprietary.  To prevent this, we have made it clear that any
-patent must be licensed for everyone's free use or not licensed at all.
-
-  The precise terms and conditions for copying, distribution and
-modification follow.
-
-                    GNU GENERAL PUBLIC LICENSE
-   TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
-
-  0. This License applies to any program or other work which contains
-a notice placed by the copyright holder saying it may be distributed
-under the terms of this General Public License.  The "Program", below,
-refers to any such program or work, and a "work based on the Program"
-means either the Program or any derivative work under copyright law:
-that is to say, a work containing the Program or a portion of it,
-either verbatim or with modifications and/or translated into another
-language.  (Hereinafter, translation is included without limitation in
-the term "modification".)  Each licensee is addressed as "you".
-
-Activities other than copying, distribution and modification are not
-covered by this License; they are outside its scope.  The act of
-running the Program is not restricted, and the output from the Program
-is covered only if its contents constitute a work based on the
-Program (independent of having been made by running the Program).
-Whether that is true depends on what the Program does.
-
-  1. You may copy and distribute verbatim copies of the Program's
-source code as you receive it, in any medium, provided that you
-conspicuously and appropriately publish on each copy an appropriate
-copyright notice and disclaimer of warranty; keep intact all the
-notices that refer to this License and to the absence of any warranty;
-and give any other recipients of the Program a copy of this License
-along with the Program.
-
-You may charge a fee for the physical act of transferring a copy, and
-you may at your option offer warranty protection in exchange for a fee.
-
-  2. You may modify your copy or copies of the Program or any portion
-of it, thus forming a work based on the Program, and copy and
-distribute such modifications or work under the terms of Section 1
-above, provided that you also meet all of these conditions:
-
-    a) You must cause the modified files to carry prominent notices
-    stating that you changed the files and the date of any change.
-
-    b) You must cause any work that you distribute or publish, that in
-    whole or in part contains or is derived from the Program or any
-    part thereof, to be licensed as a whole at no charge to all third
-    parties under the terms of this License.
-
-    c) If the modified program normally reads commands interactively
-    when run, you must cause it, when started running for such
-    interactive use in the most ordinary way, to print or display an
-    announcement including an appropriate copyright notice and a
-    notice that there is no warranty (or else, saying that you provide
-    a warranty) and that users may redistribute the program under
-    these conditions, and telling the user how to view a copy of this
-    License.  (Exception: if the Program itself is interactive but
-    does not normally print such an announcement, your work based on
-    the Program is not required to print an announcement.)
-
-These requirements apply to the modified work as a whole.  If
-identifiable sections of that work are not derived from the Program,
-and can be reasonably considered independent and separate works in
-themselves, then this License, and its terms, do not apply to those
-sections when you distribute them as separate works.  But when you
-distribute the same sections as part of a whole which is a work based
-on the Program, the distribution of the whole must be on the terms of
-this License, whose permissions for other licensees extend to the
-entire whole, and thus to each and every part regardless of who wrote it.
-
-Thus, it is not the intent of this section to claim rights or contest
-your rights to work written entirely by you; rather, the intent is to
-exercise the right to control the distribution of derivative or
-collective works based on the Program.
-
-In addition, mere aggregation of another work not based on the Program
-with the Program (or with a work based on the Program) on a volume of
-a storage or distribution medium does not bring the other work under
-the scope of this License.
-
-  3. You may copy and distribute the Program (or a work based on it,
-under Section 2) in object code or executable form under the terms of
-Sections 1 and 2 above provided that you also do one of the following:
-
-    a) Accompany it with the complete corresponding machine-readable
-    source code, which must be distributed under the terms of Sections
-    1 and 2 above on a medium customarily used for software interchange; or,
-
-    b) Accompany it with a written offer, valid for at least three
-    years, to give any third party, for a charge no more than your
-    cost of physically performing source distribution, a complete
-    machine-readable copy of the corresponding source code, to be
-    distributed under the terms of Sections 1 and 2 above on a medium
-    customarily used for software interchange; or,
-
-    c) Accompany it with the information you received as to the offer
-    to distribute corresponding source code.  (This alternative is
-    allowed only for noncommercial distribution and only if you
-    received the program in object code or executable form with such
-    an offer, in accord with Subsection b above.)
-
-The source code for a work means the preferred form of the work for
-making modifications to it.  For an executable work, complete source
-code means all the source code for all modules it contains, plus any
-associated interface definition files, plus the scripts used to
-control compilation and installation of the executable.  However, as a
-special exception, the source code distributed need not include
-anything that is normally distributed (in either source or binary
-form) with the major components (compiler, kernel, and so on) of the
-operating system on which the executable runs, unless that component
-itself accompanies the executable.
-
-If distribution of executable or object code is made by offering
-access to copy from a designated place, then offering equivalent
-access to copy the source code from the same place counts as
-distribution of the source code, even though third parties are not
-compelled to copy the source along with the object code.
-
-  4. You may not copy, modify, sublicense, or distribute the Program
-except as expressly provided under this License.  Any attempt
-otherwise to copy, modify, sublicense or distribute the Program is
-void, and will automatically terminate your rights under this License.
-However, parties who have received copies, or rights, from you under
-this License will not have their licenses terminated so long as such
-parties remain in full compliance.
-
-  5. You are not required to accept this License, since you have not
-signed it.  However, nothing else grants you permission to modify or
-distribute the Program or its derivative works.  These actions are
-prohibited by law if you do not accept this License.  Therefore, by
-modifying or distributing the Program (or any work based on the
-Program), you indicate your acceptance of this License to do so, and
-all its terms and conditions for copying, distributing or modifying
-the Program or works based on it.
-
-  6. Each time you redistribute the Program (or any work based on the
-Program), the recipient automatically receives a license from the
-original licensor to copy, distribute or modify the Program subject to
-these terms and conditions.  You may not impose any further
-restrictions on the recipients' exercise of the rights granted herein.
-You are not responsible for enforcing compliance by third parties to
-this License.
-
-  7. If, as a consequence of a court judgment or allegation of patent
-infringement or for any other reason (not limited to patent issues),
-conditions are imposed on you (whether by court order, agreement or
-otherwise) that contradict the conditions of this License, they do not
-excuse you from the conditions of this License.  If you cannot
-distribute so as to satisfy simultaneously your obligations under this
-License and any other pertinent obligations, then as a consequence you
-may not distribute the Program at all.  For example, if a patent
-license would not permit royalty-free redistribution of the Program by
-all those who receive copies directly or indirectly through you, then
-the only way you could satisfy both it and this License would be to
-refrain entirely from distribution of the Program.
-
-If any portion of this section is held invalid or unenforceable under
-any particular circumstance, the balance of the section is intended to
-apply and the section as a whole is intended to apply in other
-circumstances.
-
-It is not the purpose of this section to induce you to infringe any
-patents or other property right claims or to contest validity of any
-such claims; this section has the sole purpose of protecting the
-integrity of the free software distribution system, which is
-implemented by public license practices.  Many people have made
-generous contributions to the wide range of software distributed
-through that system in reliance on consistent application of that
-system; it is up to the author/donor to decide if he or she is willing
-to distribute software through any other system and a licensee cannot
-impose that choice.
-
-This section is intended to make thoroughly clear what is believed to
-be a consequence of the rest of this License.
-
-  8. If the distribution and/or use of the Program is restricted in
-certain countries either by patents or by copyrighted interfaces, the
-original copyright holder who places the Program under this License
-may add an explicit geographical distribution limitation excluding
-those countries, so that distribution is permitted only in or among
-countries not thus excluded.  In such case, this License incorporates
-the limitation as if written in the body of this License.
-
-  9. The Free Software Foundation may publish revised and/or new versions
-of the General Public License from time to time.  Such new versions will
-be similar in spirit to the present version, but may differ in detail to
-address new problems or concerns.
-
-Each version is given a distinguishing version number.  If the Program
-specifies a version number of this License which applies to it and "any
-later version", you have the option of following the terms and conditions
-either of that version or of any later version published by the Free
-Software Foundation.  If the Program does not specify a version number of
-this License, you may choose any version ever published by the Free Software
-Foundation.
-
-  10. If you wish to incorporate parts of the Program into other free
-programs whose distribution conditions are different, write to the author
-to ask for permission.  For software which is copyrighted by the Free
-Software Foundation, write to the Free Software Foundation; we sometimes
-make exceptions for this.  Our decision will be guided by the two goals
-of preserving the free status of all derivatives of our free software and
-of promoting the sharing and reuse of software generally.
-
-                            NO WARRANTY
-
-  11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW.  EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED
-OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
-MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE ENTIRE RISK AS
-TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU.  SHOULD THE
-PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING,
-REPAIR OR CORRECTION.
-
-  12. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES,
-INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING
-OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED
-TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY
-YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER
-PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE
-POSSIBILITY OF SUCH DAMAGES.
-
-                     END OF TERMS AND CONDITIONS
-
-            How to Apply These Terms to Your New Programs
-
-  If you develop a new program, and you want it to be of the greatest
-possible use to the public, the best way to achieve this is to make it
-free software which everyone can redistribute and change under these terms.
-
-  To do so, attach the following notices to the program.  It is safest
-to attach them to the start of each source file to most effectively
-convey the exclusion of warranty; and each file should have at least
-the "copyright" line and a pointer to where the full notice is found.
-
-    <one line to give the program's name and a brief idea of what it does.>
-    Copyright (C) <year>  <name of author>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-
-Also add information on how to contact you by electronic and paper mail.
-
-If the program is interactive, make it output a short notice like this
-when it starts in an interactive mode:
-
-    Gnomovision version 69, Copyright (C) year name of author
-    Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w'.
-    This is free software, and you are welcome to redistribute it
-    under certain conditions; type `show c' for details.
-
-The hypothetical commands `show w' and `show c' should show the appropriate
-parts of the General Public License.  Of course, the commands you use may
-be called something other than `show w' and `show c'; they could even be
-mouse-clicks or menu items--whatever suits your program.
-
-You should also get your employer (if you work as a programmer) or your
-school, if any, to sign a "copyright disclaimer" for the program, if
-necessary.  Here is a sample; alter the names:
-
-  Yoyodyne, Inc., hereby disclaims all copyright interest in the program
-  `Gnomovision' (which makes passes at compilers) written by James Hacker.
-
-  <signature of Ty Coon>, 1 April 1989
-  Ty Coon, President of Vice
-
-This General Public License does not permit incorporating your program into
-proprietary programs.  If your program is a subroutine library, you may
-consider it more useful to permit linking proprietary applications with the
-library.  If this is what you want to do, use the GNU Lesser General
-Public License instead of this License.
diff --git a/typo3/sysext/sv/Resources/Public/Icons/Extension.png b/typo3/sysext/sv/Resources/Public/Icons/Extension.png
deleted file mode 100644
index c782b5ba8ef3074ccd41f7e5b068cb622ff4d327..0000000000000000000000000000000000000000
Binary files a/typo3/sysext/sv/Resources/Public/Icons/Extension.png and /dev/null differ
diff --git a/typo3/sysext/sv/composer.json b/typo3/sysext/sv/composer.json
deleted file mode 100644
index 811caa182ca55a8bc2b021b17f178a9ba686b89f..0000000000000000000000000000000000000000
--- a/typo3/sysext/sv/composer.json
+++ /dev/null
@@ -1,33 +0,0 @@
-{
-	"name": "typo3/cms-sv",
-	"type": "typo3-cms-framework",
-	"description": "TYPO3 Core",
-	"homepage": "https://typo3.org",
-	"license": ["GPL-2.0+"],
-
-	"require": {
-		"typo3/cms-core": "*"
-	},
-	"replace": {
-		"sv": "*"
-	},
-	"extra": {
-		"typo3/cms": {
-			"Package": {
-				"protected": true,
-				"partOfFactoryDefault": true,
-				"partOfMinimalUsableSystem": true
-			}
-		}
-	},
-	"autoload": {
-		"psr-4": {
-			"TYPO3\\CMS\\Sv\\": "Classes/"
-		}
-	},
-	"autoload-dev": {
-		"psr-4": {
-			"TYPO3\\CMS\\Sv\\Tests\\": "Tests/"
-		}
-	}
-}
diff --git a/typo3/sysext/sv/ext_emconf.php b/typo3/sysext/sv/ext_emconf.php
deleted file mode 100644
index 99d15e7acd2a1e5599bc2157861cff98f4ffb77f..0000000000000000000000000000000000000000
--- a/typo3/sysext/sv/ext_emconf.php
+++ /dev/null
@@ -1,21 +0,0 @@
-<?php
-$EM_CONF[$_EXTKEY] = [
-    'title' => 'TYPO3 System Services',
-    'description' => 'The core/default services. This includes the default authentication services for now.',
-    'category' => 'services',
-    'state' => 'stable',
-    'uploadfolder' => 0,
-    'createDirs' => '',
-    'clearCacheOnLoad' => 1,
-    'author' => 'Rene Fritz',
-    'author_email' => 'r.fritz@colorcube.de',
-    'author_company' => 'Colorcube',
-    'version' => '9.0.0',
-    'constraints' => [
-        'depends' => [
-            'typo3' => '9.0.0-9.0.99',
-        ],
-        'conflicts' => [],
-        'suggests' => [],
-    ],
-];
diff --git a/typo3/sysext/sv/ext_localconf.php b/typo3/sysext/sv/ext_localconf.php
deleted file mode 100644
index 5182966c1cfa0ed24da7d901f91a81926151741b..0000000000000000000000000000000000000000
--- a/typo3/sysext/sv/ext_localconf.php
+++ /dev/null
@@ -1,20 +0,0 @@
-<?php
-defined('TYPO3_MODE') or die();
-
-// Register base authentication service
-\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::addService(
-    'sv',
-    'auth',
-    \TYPO3\CMS\Sv\AuthenticationService::class,
-    [
-        'title' => 'User authentication',
-        'description' => 'Authentication with username/password.',
-        'subtype' => 'getUserBE,getUserFE,authUserFE,getGroupsFE,processLoginDataBE,processLoginDataFE',
-        'available' => true,
-        'priority' => 50,
-        'quality' => 50,
-        'os' => '',
-        'exec' => '',
-        'className' => \TYPO3\CMS\Sv\AuthenticationService::class
-    ]
-);
diff --git a/typo3/sysext/sv/Tests/Functional/AuthenticationServiceTest.php b/typo3/sysext/core/Tests/Functional/Authentication/AuthenticationServiceTest.php
similarity index 84%
rename from typo3/sysext/sv/Tests/Functional/AuthenticationServiceTest.php
rename to typo3/sysext/core/Tests/Functional/Authentication/AuthenticationServiceTest.php
index a7fa385b35c994ad8f325bf24fb5371f2bdd753c..15921f60194f2222c69506166534e4ffe57c85bd 100644
--- a/typo3/sysext/sv/Tests/Functional/AuthenticationServiceTest.php
+++ b/typo3/sysext/core/Tests/Functional/Authentication/AuthenticationServiceTest.php
@@ -1,6 +1,6 @@
 <?php
 declare(strict_types=1);
-namespace TYPO3\CMS\Sv\Tests\Functional;
+namespace TYPO3\CMS\Core\Tests\Functional\Authentication;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,11 +14,11 @@ namespace TYPO3\CMS\Sv\Tests\Functional;
  *
  * The TYPO3 project - inspiring people to share!
  */
+use TYPO3\CMS\Core\Authentication\AuthenticationService;
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
-use TYPO3\CMS\Sv\AuthenticationService;
 
 /**
  * Testcase for class \TYPO3\CMS\Sv\AuthenticationService
  */
 class AuthenticationServiceTest extends \TYPO3\TestingFramework\Core\Functional\FunctionalTestCase
 {
@@ -31,7 +31,7 @@ class AuthenticationServiceTest extends \TYPO3\TestingFramework\Core\Functional\
     {
         $this->subject = new AuthenticationService();
         parent::setUp();
-        $this->importDataSet(ORIGINAL_ROOT . 'typo3/sysext/sv/Tests/Functional/Fixtures/be_users.xml');
+        $this->importDataSet(ORIGINAL_ROOT . 'typo3/sysext/core/Tests/Functional/Fixtures/be_users.xml');
     }
 
     /**
@@ -14,11 +14,11 @@ namespace TYPO3\CMS\Sv\Tests\Functional;
 
 /**
- * Testcase for class \TYPO3\CMS\Sv\AuthenticationService
+ * Testcase for class \TYPO3\CMS\Core\Authentication\AuthenticationService
  */
 class AuthenticationServiceTest extends \TYPO3\TestingFramework\Core\Functional\FunctionalTestCase
diff --git a/typo3/sysext/rsaauth/Classes/RsaAuthService.php b/typo3/sysext/rsaauth/Classes/RsaAuthService.php
index 85a2a4d37b62fef5b72e8110b5373b410b33a5fd..5a2b08a789e5fbae5d8d323b0d83a46eef5d414b 100644
--- a/typo3/sysext/rsaauth/Classes/RsaAuthService.php
+++ b/typo3/sysext/rsaauth/Classes/RsaAuthService.php
@@ -14,16 +14,17 @@ namespace TYPO3\CMS\Rsaauth;
  * The TYPO3 project - inspiring people to share!
  */
 
+use TYPO3\CMS\Core\Authentication\AuthenticationService;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 
 /**
  * Service "RSA authentication" for the "rsaauth" extension. This service will
  * authenticate a user using hos password encoded with one time public key. It
  * uses the standard TYPO3 service to do all dirty work. Firsts, it will decode
  * the password and then pass it to the parent service ('sv'). This ensures that it
  * always works, even if other TYPO3 internals change.
  */
-class RsaAuthService extends \TYPO3\CMS\Sv\AuthenticationService
+class RsaAuthService extends AuthenticationService
 {
     /**
      * @var RsaEncryptionDecoder
@@ -14,16 +14,17 @@ namespace TYPO3\CMS\Rsaauth;
  * authenticate a user using hos password encoded with one time public key. It
  * uses the standard TYPO3 service to do all dirty work. Firsts, it will decode
- * the password and then pass it to the parent service ('sv'). This ensures that it
+ * the password and then pass it to the parent service ('core'). This ensures that it
  * always works, even if other TYPO3 internals change.
  */